// Ion sensing subroutines for MSP430 
// Copyright (C) 2002  Ville Vartiovaara
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Author: Ville Vartiovaara Ville.Vartiovaara@hut.fi


#include  <msp430x14x.h>
#include "../main.h"
#include "datainit.h"

unsigned int pointer;

void InitAdc(void)
{    
   P6SEL |= 0x01;                        // Enable A/D channel A0
   ADC12CTL0 = ADC12ON;                  // Turn on ADC12, set sampling time
   ADC12CTL1 = SHP;                      // Use sampling timer, set mode
   ADC12IE = 0x01;                       // Enable ADC12IFG.0
   ADC12CTL0 |= ENC;                     // Enable conversions   
   TACTL = TASSEL1 + TACLR;              // SMCLK clear TAR
   CCTL0 = CCIE;                         // CCR0 interrupt enabled
   CCR0 = 520;
//   TACTL |= MC0;                         // Start Timer_A in upmode  
   _EINT();                              // Enable interrupts
   
   
//   ADC12CTL0 |= ADC12SC;                 // Start conversion

   
   pointer=0;

}

// Timer A0 interrupt service routine
interrupt[TIMERA0_VECTOR] void Timer_A (void)
{
   if(delay==0) // If spark delay is gone
     {
	ADC12CTL0 |= ADC12SC;  // Start conversion
	pos++;
	if(!(P4IN & 0x01)) // make tdc_start and tdc_end indexes point the correct value
	  {
	     if(!tdc_started)
	       {
		  tdc_start=pos;
		  tdc_started=1;
	       }
	  }	    
	else if((tdc_started)&&(!tdc_ended)) // determine how long we should be sampling
	  {
	     tdc_end=pos;
	     tdc_ended=1;
	     len=(tdc_end-tdc_start);
	     len+=len;		
	     len+=len+(tdc_end-tdc_start); // len=5*(tdc_end-tdc_start) == 100degs
	     if(len > 250) 
	       len=250;
	  }
     }
   else // still waiting for spark to decay
     {
	delay--;

	if(!(P4IN & 0x01)) // no 'pos' yet, so start and end values are put below zero..
	  {
	     tdc_start--;
	     if(!tdc_started)
	       {
		  tdc_started=1;
	       }
	  }
	else if(tdc_started)
	  {
	     tdc_end--;
	     if(!tdc_ended)
	       {
		  tdc_ended=1;
      		  len=tdc_end-tdc_start; 	//
		  len+=len;		 	//
		  len+=len;		 	//
		  len+=len+(tdc_end-tdc_start);	// len=5*(tdc_end-tdc_start) == 100degs  
		  if(len>250) len=250;
	       }
	  }   
     }
 }





// ADC Conversion done
interrupt[ADC_VECTOR] void ADC12ISR (void)
{
   result = ADC12MEM0;                  // Move results, IFG is cleared
}
