// Ion sensing subroutines for MSP430 
// Copyright (C) 2002  Ville Vartiovaara
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// Author: Ville Vartiovaara Ville.Vartiovaara@hut.fi

#include  <msp430x14x.h>
#include <stdio.h>
#include "lib/uart.h"
#include "lib/clock_control.h"
#include "lib/datainit.h"
#include "lib/adc.h"
#include "routines/process_data.h"


// First initialize, then start an endless loop:
// 1. wait for spark or tdc trigger
// 2. sample data at a predetermined speed
// 3. process the data
// 4. spit out the result via RS-232
// 5. back to 1. 


// This is just a primitive main loop that only keeps on sampling, processing and
// spitting data out. No bidir comms with PC or similar provided.

extern void getsample(void); // the sampling routine

unsigned int peak_deg; 	// The Thing
unsigned char pd[30];  	// for debug info printing (sprintf)
unsigned int pos;      	// global data index
unsigned int tdc_start, tdc_end, len, ymax, divcount, tdc_started, tdc_ended;
unsigned int result, tdc_debug; // several global mem addresses
unsigned int delay; // used by the sampling routine (samplerate)
unsigned int spark; //
unsigned int peak_x, peak_y, deg, step;

//DEBUG
unsigned int fpeak_x; // flame term peak x coordinate


void main(void)
{    
   unsigned char c, c1;
   unsigned int ijk;

   WDTCTL=WDTPW+WDTHOLD;
   
   InitClk();		// clock system and port setup
   DCOCTL=0x0E0;	
   P5DIR |= 0x070;
   P5SEL |= 0x070;
   
   InitUart(); // initialize peripherals
   InitAdc();
   
   P1DIR |= 0x0F;      // input and output ports
   P4DIR = 0x00;
   
   result=0;		// hmm...
   divcount=1;
   ymax=0;

   CCR0=1000; // initial sampling speed = 8kHz
   delay=8;   // spark duration (1ms) expressed in samples (8000/CCR0)
   
   
   P1OUT=0x0F;		// debug led
   
   
   for (;;)
     {		

	P1OUT ^= 0x01; // toggle led

// BEGINNING OF THE MAIN LOOP
	
	getsample();   // do some sampling

	peak_deg=0;    // ... to be sure ...
	process_data();// find the PPP -> result in peak_deg

// END OF MAIN LOOP
	

	
	// dump result
	pd[0]=pd[1]=pd[2]=0; //pd[3]=pd[4]=pd[5]=pd[6]=pd[7]=pd[8]=pd[9]=pd[10]=pd[11]=pd[12]=pd[13]=pd[14]=pd[15]=pd[16]=pd[17]=pd[18]=pd[19]=pd[20]=pd[21]=pd[22]=pd[23]=0;
	sprintf(pd, "%d", peak_x);
	c=pd[0];
	SendChar(c);
	c=pd[1];
	SendChar(c);
	c=pd[2];
	SendChar(c);
	SendChar(10);
	SendChar(13);

}


	
